@@ -217,6 +217,8 @@ class ControllerNode(object):
 
             msg_id = binascii.unhexlify(msg.get('token'))
             if 'data' in msg:
+                if not msg['data']:
+                    msg['data'] = b''
                 self.send(msg_id, msg['data'], is_rpc=True)
                 gc.collect()
             else:
@@ -509,14 +511,18 @@ class ControllerNode(object):
 
         parent_token = msg['token']
 
-        params = {}
         for filename in filenames:
+            # make a new message
             worker_msg = msg.copy()
             worker_msg['parent_token'] = parent_token
             worker_msg['filename'] = filename
-            params['args'] = list(args)
+
+            # make parameters
+            params = {
+                'args': list(args),
+                'kwargs': kwargs
+            }
             params['args'][0] = filename
-            params['kwargs'] = kwargs
             worker_msg['params'] = params
 
             # Make up a new token for the message sent to the workers, and collect the responses using that id
